@@ -58,7 +58,9 @@
 # define F4(T1,P1,T2,P2,T3,P3,T4,P4) (T1 P1, T2 P2, T3 P3, T4 P4)
 # define F5(T1,P1,T2,P2,T3,P3,T4,P4,T5,P5) (T1 P1, T2 P2, T3 P3, T4 P4, T5 P5)
 # define F2V(T1,P1,T2,P2)	(T1 P1, T2 P2, ...)
-# define __P(x)			x
+# ifndef __P
+#   define __P(x)			x
+# endif
 #else
 # define F0()			()
 # define F1(T1,P1)		(P1) T1 P1;
@@ -67,7 +69,9 @@
 # define F4(T1,P1,T2,P2,T3,P3,T4,P4) (P1,P2,P3,P4) T1 P1; T2 P2; T3 P3; T4 P4;
 # define F5(T1,P1,T2,P2,T3,P3,T4,P4,T5,P5) (P1,P2,P3,P4,P5) T1 P1; T2 P2; T3 P3; T4 P4;T5 P5;
 # define F2V(T1,P1,T2,P2)	(P1,P2,va_alist) T1 P1; T2 P2; va_dcl
-# define __P(x)			()
+# ifndef __P
+#   define __P(x)			()
+# endif
 # ifndef const
 #  define const
 # endif
@@ -295,6 +299,7 @@ static void Initialize F4(Widget, request, Widget, new, ArgList, arg,
     p->fileList = 0;
     p->fileIndex= 0;
     p->titleW   = None;
+    p->updateTimer = 0;
 
     if (p->titleString) {
 	p->titleString = XtNewString(p->titleString);
