@@ -10,7 +10,7 @@
 # This file is part of Xcra.
 #
 # Xcra is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
+# It under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 #
@@ -212,6 +212,11 @@ sub ReadCra {
      &message($Indent . "Reading $file...");
      if (open(CRAFILE, $file)) {
 
+	@tskTable = keys %timeTable;
+	foreach $task (@tskTable) {
+	    $timeTable{$task} = "";
+	}
+
 	#
 	# Read in the file filling the different tables
 	#
@@ -283,6 +288,9 @@ sub ReadReportTimes {
 	}
      } else {
 
+	foreach $task (@tskTable) {
+	    $reportTable{$task} = "0";
+	}
 	#
 	# Read in the file filling the different tables
 	#
@@ -399,11 +407,11 @@ sub ReadWeekTimes {
     last Rescan;
     }
 #    foreach $tsk (@tskTable) {
-#	printf("%s %s", $tsk, $weekTime{$tsk});
+#	printf("%s %s [", $tsk, $weekTime{$tsk});
 #	for ($v = 1; $v < 16; $v = $v + 1) {
 #	    printf("%d ", &GetWeekTime($v, $tsk));
 #	}
-#	printf("\n");
+#	printf("]\n");
 #    }
 
 	#
@@ -425,7 +433,7 @@ sub ReadWeekTimes {
 # ######################################################################
 
 #
-# Role :	Build a table which indicates the first day and last
+# X Role :	Build a table which indicates the first day and last
 #		day of a Chorus week (quinzaine). The result is saved
 #		in global tables:
 #
@@ -454,7 +462,7 @@ sub FindWeeks {
 
 	#
 	# Find the time which correspond to `1/1/$yearToFind'
-	# (Note that leap years are handled by `localtime')
+	# Note that leap years are handled by `localtime'
 	# 
     $theTime = time();
     yearScan:
@@ -491,9 +499,9 @@ sub FindWeeks {
 	}
 
 		#
-		# This is monday
+		# This is monday or the first day of the year.
 		#
-	if ($wday == 1) {
+	if ($wday == 1 || $chorusWeek == 0) {
 	    $Week = $Week + 1;
 	    if (($Week % 2) == 1) {
 		$chorusWeek = $chorusWeek + 1;
@@ -920,6 +928,33 @@ sub LdbPrintSummary {
 
     printf("%s %d\n", $CurrentTaskRef, int($total / 3600));
 }
+
+sub LdbFindTasks {
+    local($nameFlag) = 0;
+    local($taskRef);
+    local(%taskList);
+
+    while (<STDIN>) {
+	chop;
+	if ($nameFlag) {
+	    $taskList{$_} = $taskRef;
+	    $nameFlag = 0;
+
+	} elsif (/^\.LI/) {
+	    $taskRef = $_;
+	    $taskRef =~ s,.LI ,,;
+	    $nameFlag = 1;
+	}
+    }
+    local(@list) = sort { $a le $b } keys %taskList;
+    foreach $taskRef (@list) {
+	local($ref) = $taskList{$taskRef};
+	print "T=$taskRef\n";
+	print "R=$ref\n";
+	print "C= 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0";
+	print " 0 0 0 0 0 0 0 0 0\n";
+    }
+}
 #endif
 
 # ######################################################################
@@ -1708,6 +1743,7 @@ $weekReportLast = 0;
 $dayNum  = 0;
 $yearNum = -1;
 $monNum  = -1;
+$queryReportFlag = 0;
 
 #
 # Parse some arguments
@@ -1736,6 +1772,9 @@ while (@ARGV) {
 	$printExactTime   = 0;
 	&MethodClass("Empty", "$PrintMethods");
 	&MethodClass("Ldb", "PrintHeader PrintTailer PrintSummary");
+
+    } elsif (/^-ldb-query$/) {
+	$queryReportFlag = 1;
 #endif
 
     } elsif (/^-oleo$/) {
@@ -1805,6 +1844,14 @@ $userName = &CraName;
 $userName = "";
 #endif
 
+#ifdef HAVE_LDBUPDATE
+
+if ($queryReportFlag) {
+    &LdbFindTasks;
+    exit 0;
+}
+#endif
+
 if ($dayNum != 0) {
     #printf("%s %s %s\n", $dayNum, $monthNum, $yearNum);
     $week = &FindWeek($dayNum, $monthNum, $yearNum);
@@ -1856,6 +1903,7 @@ if ($fullYear) {
 	# Compute & print the report
 	#
     &WeeklyReport($week, $curYear);
+    $week = int(($week + 1) / 2);
     &WriteReportTimes($week, $curYear)
 	if ($preserve == 0 && $printExactTime == 0);
 }
