@@ -71,7 +71,7 @@ three kinds of buttons:
 next-help
 whatIs XCra[Main Window] taskMgr[Task Manager] noteMgr[Note Manager] general[General Information]
 
-		XCRA 2.1
+		XCRA 2.2
 
 Xcra is a tool which will help you recording the time
 spent on various tasks, and manage a set of notes
@@ -124,7 +124,7 @@ associated  to a notes file, a default notes file is used.
 next-help
 general whatIs[What is Xcra?] copyright[Copyright] author[Author] bug[Bug report]
 		General Information
-		     XCra 2.1
+		     XCra 2.2
 
 
 XCra is a small tool to help people keep track of where they
@@ -139,11 +139,11 @@ author general[General Information] copyright[Copyright] bug[Bug report]
 
 Stephane Carrez
 
-317, rue de Vaugirard
-75015 Paris
+17, rue Foucher Lepelletier
+92130 Issy Les Moulineaux
 FRANCE
 
-ciceron@chorus.fr
+Stephane.Carrez@worldnet.fr
 next-help
 bug general[General Information] copyright[Copyright] author[Author]
 		Bug report
@@ -151,7 +151,7 @@ bug general[General Information] copyright[Copyright] author[Author]
 Improvements, suggestions, bug-corrections, bug-reports
 are welcome. They may be sent to the following e-mail address:
 
-	ciceron@chorus.fr
+	Stephane.Carrez@worldnet.fr
 
 next-help
 ref addTask[Add a task] delTask[Remove a task] dialogs[Dialog boxes]
@@ -197,16 +197,30 @@ addTask delTask[Delete a task] dialogs[Dialog boxes]
 		Add a new Task
 
 The `Create Task' dialog box allows you to create a new task.
-The task is associated a logical name and a reference name.
+The task is associated with a logical name and a reference name.
 The logical name is printed in dialog boxes and the
 reference name is the task identification used by external
 tools.
+#ifdef HAVE_IMPORT
+A list of imported tasks is displayed and selecting one
+task of the list will put the name and reference of the
+selected task in the text edition fields. It is then possible
+validate the dialog box or to modify the task or
+reference name.
+
+The list of imported tasks is read from the file `import.tasks'
+which is automatically updated by an external command when
+this is needed.
+#endif
 
 Fields:
 -------
 Task name		Logical name of the task
 			(must not be empty)
 Task reference		Task reference name
+Creation date		The month when the task is created. By
+			default this is the current month. The
+			date is specified as: <month>/<year>
 
 next-help
 keys
@@ -271,7 +285,9 @@ the <left> mouse button either on the left or right
 top arrows.
 
 Once the month and the day are selected, it is possible
-to specify a time to add or subtract for several tasks.
+to specify a time for several tasks. The time can
+be added or substracted. To substract a time, the '-'
+character must be present.
 
 When all the text fields are filled correctly, the
 time of the different tasks is updated. The text
@@ -291,11 +307,12 @@ The specification of a time is as follows:
 
 When a time value is preceded by the `-' sign (minus),
 the time is negative: it is subtracted from the actual
-task time value. If a time value is not correct, the
-validation of the dialog box will cause the label
-associated with that value to be grayed. This indicates
-that the text field is not filled correctly and must be
-corrected.
+task time value. Otherwise, the time value
+is added to the actual task time value. If a time value is
+not correct, the validation of the dialog box will cause
+the label associated with that value to be grayed. This
+indicates that the text field is not filled correctly and
+must be corrected.
 
 next-help
 report addTime[Modify Time] dialogs[Dialog boxes]
@@ -629,6 +646,10 @@ The XCra main window displays three popup menu buttons:
    and edit a note. It also provides a basic search in the
    notes file.
 
+By default, it is not possible to close the main window.
+Closing the main window is only enabled when the -allow-close
+option is specified or when the allowClose resource is set
+to true.
 
 next-help
 toto
