@@ -1,5 +1,5 @@
 .\" @(#)xcra.1	6/04/95
-.\"" $Id: xcra.man.cpp,v 1.4 96/02/23 11:25:15 ciceron Exp $
+.\"" $Id: xcra.man.cpp,v 1.6 2000/02/23 08:24:48 ciceron Exp $
 .\"" Copyright (C) 1994, 1995, 1996 Stephane Carrez
 .\""
 .\"" This file is part of Xcra.
@@ -18,7 +18,7 @@
 .\"" along with this program; if not, write to the Free Software
 .\"" Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 .\""
-.TH XCRA 1 "Dec 10, 1995"
+.TH XCRA 1 "Aug 4, 1996"
 .SH NAME
 xcra \- Cra Recorder Automatic tool
 .SH SYNOPSIS
@@ -33,6 +33,8 @@ xcra \- Cra Recorder Automatic tool
 .B \-msize
 .I count
 ] [
+.B \-allow\-close
+] [
 .I toolkit-options
 ]
 .SH DESCRIPTION
@@ -134,6 +136,14 @@ Updates the task time each \fItime\fP seconds.
 Use \fIcount\fP as the maximum number of task names which can appear
 on the task popup menu.
 .\""
+.TP
+-allow-close
+By default,
+.I Xcra
+forbids you to close the main window to avoid mistakes. This option
+allows to close the main window and exit
+.IR Xcra .
+.\""
 .\""
 .SH INITIALIZATION
 Before using
@@ -274,6 +284,18 @@ is used by
 and
 .I cra-report
 to silently ignore the task when a summary is reported.
+#ifdef HAVE_IMPORT
+To help in the creation of the task,
+.I Xcra
+imports a list of tasks from an external database. The list of imported
+tasks is read from the file
+.I import.tasks
+in the cra directory. This list is rebuilt by an external command (which is
+configurable by a resource) if the file does not exist or seems
+out-of-date (more than one hour old). In the dialog box, selecting
+a task from the list will cause the task and reference of the selected
+task to be placed in the text edition fields.
+#endif
 .\""
 .IP "\fBRemove Task\fP"
 This dialog box displays the list of tasks in a scrolled window and
@@ -648,6 +670,13 @@ Boolean resource which indicates whether the bell must be rung if an
 error is detected. Default is true.
 .\""
 .TP 18
+\fBallowClose\fP (Class \fBAllowClose\fP)
+This resources enables the closing of the main
+.I Xcra
+window. When this resource is false, closing the main window is impossible.
+Default is false.
+.\""
+.TP 18
 \fBtransientShell\fP (Class \fBTransientShell\fP)
 Boolean resource which indicates whether a transient shell must be
 used for dialog boxes. Transient shells are used for dialog boxes and
@@ -731,6 +760,16 @@ Format string used by the report dialog box to determine the external
 command which must be executed.
 Default is REPORT_COMMAND.
 .\""
+#ifdef HAVE_IMPORT
+.TP 18
+\fBimportCommand\fP (Class \fBImportCommand\fP)
+Command which must be executed to build the list of imported tasks.
+The command must create or update the file
+.I import.tasks
+stored the cra directory.
+Default is IMPORT_COMMAND.
+#endif
+.\""
 .TP 18
 \fBprintCommand\fP (Class \fBPrintCommand\fP)
 Command which must be executed to print a note.
